;; Generated package description from ob-asymptote.el  -*- no-byte-compile: t -*-
(define-package "ob-asymptote" "1.0" "Babel Functions for Asymptote" 'nil :commit "8445b1cccc131e317b464a3ebc461301b9e2ca30" :maintainer '("Jarmo Hurri" . "jarmo.hurri@iki.fi") :keywords '("literate programming" "reproducible research") :url "https://github.com/hurrja/ob-asymptote")
